@@ -1,18 +1,19 @@
 # frozen_string_literal: true
-require 'rubygems/test_case'
-require 'rubygems/commands/lock_command'
+
+require_relative "helper"
+require "rubygems/commands/lock_command"
 
 class TestGemCommandsLockCommand < Gem::TestCase
   def setup
     super
 
-    @a1 = quick_gem 'a', '1'
-    @b1 = quick_gem 'b', '1' do |s|
-      s.add_runtime_dependency 'a'
+    @a1 = quick_gem "a", "1"
+    @b1 = quick_gem "b", "1" do |s|
+      s.add_runtime_dependency "a"
     end
 
-    @d1 = quick_gem 'd', '1' do |s|
-      s.add_runtime_dependency 'z'
+    @d1 = quick_gem "d", "1" do |s|
+      s.add_runtime_dependency "z"
     end
 
     @cmd = Gem::Commands::LockCommand.new
@@ -32,7 +33,7 @@ gem 'a', '= 1'
     EXPECTED
 
     assert_equal expected, @ui.output
-    assert_equal '', @ui.error
+    assert_equal "", @ui.error
   end
 
   def test_execute_missing_dependency
@@ -49,18 +50,18 @@ gem 'd', '= 1'
     EXPECTED
 
     assert_equal expected, @ui.output
-    assert_equal '', @ui.error
+    assert_equal "", @ui.error
   end
 
   def test_execute_strict
     @cmd.handle_options %w[c-1 --strict]
 
-    e = assert_raises Gem::Exception do
+    e = assert_raise Gem::Exception do
       use_ui @ui do
         @cmd.execute
       end
     end
 
-    assert_equal 'Could not find gem c-1, try using the full name', e.message
+    assert_equal "Could not find gem c-1, try using the full name", e.message
   end
 end
