@@ -1,6 +1,7 @@
 # frozen_string_literal: true
-require_relative 'helper'
-require 'rubygems/commands/update_command'
+
+require_relative "helper"
+require "rubygems/commands/update_command"
 
 class TestGemCommandsUpdateCommand < Gem::TestCase
   def setup
@@ -12,20 +13,20 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.options[:document] = []
 
     @specs = spec_fetcher do |fetcher|
-      fetcher.download 'a', 1
-      fetcher.download 'a', 2
-      fetcher.download 'a', '3.a'
+      fetcher.download "a", 1
+      fetcher.download "a", 2
+      fetcher.download "a", "3.a"
     end
 
-    @a1_path  = @specs['a-1'].cache_file
-    @a2_path  = @specs['a-1'].cache_file
-    @a3a_path = @specs['a-3.a'].cache_file
+    @a1_path  = @specs["a-1"].cache_file
+    @a2_path  = @specs["a-1"].cache_file
+    @a3a_path = @specs["a-3.a"].cache_file
   end
 
   def test_execute
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
-      fetcher.spec 'a', 1
+      fetcher.download "a", 2
+      fetcher.spec "a", 1
     end
 
     @cmd.options[:args] = []
@@ -43,11 +44,11 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_multiple
     spec_fetcher do |fetcher|
-      fetcher.download 'a',  2
-      fetcher.download 'ab', 2
+      fetcher.download "a",  2
+      fetcher.download "ab", 2
 
-      fetcher.spec 'a',  1
-      fetcher.spec 'ab', 1
+      fetcher.spec "a",  1
+      fetcher.spec "ab", 1
     end
 
     @cmd.options[:args] = %w[a]
@@ -65,7 +66,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -87,7 +88,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_at_latest
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', Gem::VERSION do |s|
+      fetcher.download "rubygems-update", Gem::VERSION do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -108,9 +109,9 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_when_latest_does_not_support_your_ruby
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
-        s.required_ruby_version = '> 9'
+        s.required_ruby_version = "> 9"
       end
     end
 
@@ -133,11 +134,11 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_multiple
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 8 do |s|
+      fetcher.download "rubygems-update", 8 do |s|
         s.files = %w[setup.rb]
       end
 
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -159,7 +160,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_update_installed
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 8 do |s|
+      fetcher.download "rubygems-update", 8 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -170,7 +171,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.execute
 
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -193,7 +194,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_update_installed_in_non_default_gem_path
     rubygems_update_spec = quick_gem "rubygems-update", 9 do |s|
-      write_file File.join(@tempdir, 'setup.rb')
+      write_file File.join(@tempdir, "setup.rb")
 
       s.files += %w[setup.rb]
     end
@@ -224,11 +225,11 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_specific
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 8 do |s|
+      fetcher.download "rubygems-update", 8 do |s|
         s.files = %w[setup.rb]
       end
 
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -250,7 +251,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_specific_older_than_minimum_supported_rubygems
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', "2.5.1" do |s|
+      fetcher.download "rubygems-update", "2.5.1" do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -279,7 +280,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_specific_older_than_3_2_removes_plugins_dir
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 3.1 do |s|
+      fetcher.download "rubygems-update", 3.1 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -297,7 +298,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.options[:system]        = "3.1"
 
     FileUtils.mkdir_p Gem.plugindir
-    write_file File.join(Gem.plugindir, 'a_plugin.rb')
+    write_file File.join(Gem.plugindir, "a_plugin.rb")
 
     @cmd.execute
 
@@ -306,7 +307,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_specific_newer_than_or_equal_to_3_2_leaves_plugins_dir_alone
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', "3.2.a" do |s|
+      fetcher.download "rubygems-update", "3.2.a" do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -324,7 +325,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.options[:system]        = "3.2.a"
 
     FileUtils.mkdir_p Gem.plugindir
-    plugin_file = File.join(Gem.plugindir, 'a_plugin.rb')
+    plugin_file = File.join(Gem.plugindir, "a_plugin.rb")
     write_file plugin_file
 
     @cmd.execute
@@ -335,11 +336,11 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_system_specifically_to_latest_version
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 8 do |s|
+      fetcher.download "rubygems-update", 8 do |s|
         s.files = %w[setup.rb]
       end
 
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -400,12 +401,12 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.options[:system] = true
     @cmd.options[:silent] = true
 
-    assert_equal true, @cmd.update_rubygems_arguments.include?('--silent')
+    assert_equal true, @cmd.update_rubygems_arguments.include?("--silent")
   end
 
   def test_execute_system_silent
     spec_fetcher do |fetcher|
-      fetcher.download 'rubygems-update', 9 do |s|
+      fetcher.download "rubygems-update", 9 do |s|
         s.files = %w[setup.rb]
       end
     end
@@ -429,12 +430,12 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_dependencies
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2, 'b' => 2, 'c' => 2
-      fetcher.download 'b', 2
-      fetcher.download 'c', 2
+      fetcher.download "a", 2, "b" => 2, "c" => 2
+      fetcher.download "b", 2
+      fetcher.download "c", 2
 
-      fetcher.spec 'a', 1, 'c' => '1.2'
-      fetcher.spec 'c', '1.2'
+      fetcher.spec "a", 1, "c" => "1.2"
+      fetcher.spec "c", "1.2"
     end
 
     Gem::Specification.reset
@@ -456,8 +457,8 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_rdoc
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
-      fetcher.spec 'a', 1
+      fetcher.download "a", 2
+      fetcher.spec "a", 1
     end
 
     Gem.done_installing(&Gem::RDoc.method(:generation_hook))
@@ -472,16 +473,16 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
     wait_for_child_process_to_exit
 
-    a2 = @specs['a-2']
+    a2 = @specs["a-2"]
 
-    assert_path_exist File.join(a2.doc_dir, 'rdoc')
+    assert_path_exist File.join(a2.doc_dir, "rdoc")
   end
 
   def test_execute_named
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
+      fetcher.download "a", 2
 
-      fetcher.spec 'a', 1
+      fetcher.spec "a", 1
     end
 
     @cmd.options[:args] = %w[a]
@@ -500,10 +501,10 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_named_some_up_to_date
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
-      fetcher.spec 'a', 1
+      fetcher.download "a", 2
+      fetcher.spec "a", 1
 
-      fetcher.spec 'b', 2
+      fetcher.spec "b", 2
     end
 
     @cmd.options[:args] = %w[a b]
@@ -523,7 +524,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_named_up_to_date
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2
+      fetcher.spec "a", 2
     end
 
     @cmd.options[:args] = %w[a]
@@ -535,15 +536,16 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     out = @ui.output.split "\n"
     assert_equal "Updating installed gems", out.shift
     assert_equal "Nothing to update", out.shift
+    assert_equal "Gems already up-to-date: a", out.shift
 
     assert_empty out
   end
 
   def test_execute_named_up_to_date_prerelease
     spec_fetcher do |fetcher|
-      fetcher.download 'a', '3.a'
+      fetcher.download "a", "3.a"
 
-      fetcher.gem 'a', 2
+      fetcher.gem "a", 2
     end
 
     @cmd.options[:args] = %w[a]
@@ -563,7 +565,7 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_execute_up_to_date
     spec_fetcher do |fetcher|
-      fetcher.gem 'a', 2
+      fetcher.gem "a", 2
     end
 
     @cmd.options[:args] = []
@@ -605,73 +607,73 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_fetch_remote_gems
     specs = spec_fetcher do |fetcher|
-      fetcher.gem 'a', 1
-      fetcher.gem 'a', 2
+      fetcher.gem "a", 1
+      fetcher.gem "a", 2
     end
 
     expected = [
-      [Gem::NameTuple.new('a', v(2), Gem::Platform::RUBY),
+      [Gem::NameTuple.new("a", v(2), Gem::Platform::RUBY),
        Gem::Source.new(@gem_repo)],
     ]
 
-    assert_equal expected, @cmd.fetch_remote_gems(specs['a-1'])
+    assert_equal expected, @cmd.fetch_remote_gems(specs["a-1"])
   end
 
   def test_fetch_remote_gems_error
     Gem.sources.replace %w[http://nonexistent.example]
 
     assert_raise Gem::RemoteFetcher::FetchError do
-      @cmd.fetch_remote_gems @specs['a-1']
+      @cmd.fetch_remote_gems @specs["a-1"]
     end
   end
 
   def test_fetch_remote_gems_mismatch
-    platform = Gem::Platform.new 'x86-freebsd9'
+    platform = Gem::Platform.new "x86-freebsd9"
 
     specs = spec_fetcher do |fetcher|
-      fetcher.spec 'a', 1
-      fetcher.spec 'a', 2
+      fetcher.spec "a", 1
+      fetcher.spec "a", 2
 
-      fetcher.spec 'a', 2 do |s|
+      fetcher.spec "a", 2 do |s|
         s.platform = platform
       end
     end
 
     expected = [
-      [Gem::NameTuple.new('a', v(2), Gem::Platform::RUBY),
+      [Gem::NameTuple.new("a", v(2), Gem::Platform::RUBY),
        Gem::Source.new(@gem_repo)],
     ]
 
-    assert_equal expected, @cmd.fetch_remote_gems(specs['a-1'])
+    assert_equal expected, @cmd.fetch_remote_gems(specs["a-1"])
   end
 
   def test_fetch_remote_gems_prerelease
     specs = spec_fetcher do |fetcher|
-      fetcher.gem 'a', 1
-      fetcher.gem 'a', 2
-      fetcher.gem 'a', '3.a'
+      fetcher.gem "a", 1
+      fetcher.gem "a", 2
+      fetcher.gem "a", "3.a"
     end
 
     @cmd.options[:prerelease] = true
 
     expected = [
-      [Gem::NameTuple.new('a', v(2), Gem::Platform::RUBY),
+      [Gem::NameTuple.new("a", v(2), Gem::Platform::RUBY),
        Gem::Source.new(@gem_repo)],
-      [Gem::NameTuple.new('a', v('3.a'), Gem::Platform::RUBY),
+      [Gem::NameTuple.new("a", v("3.a"), Gem::Platform::RUBY),
        Gem::Source.new(@gem_repo)],
     ]
 
-    assert_equal expected, @cmd.fetch_remote_gems(specs['a-1'])
+    assert_equal expected, @cmd.fetch_remote_gems(specs["a-1"])
   end
 
   def test_handle_options_system
     @cmd.handle_options %w[--system]
 
     expected = {
-      :args     => [],
+      :args => [],
       :document => %w[ri],
-      :force    => false,
-      :system   => true,
+      :force => false,
+      :system => true,
     }
 
     assert_equal expected, @cmd.options
@@ -687,10 +689,10 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     @cmd.handle_options %w[--system 1.3.7]
 
     expected = {
-      :args     => [],
+      :args => [],
       :document => %w[ri],
-      :force    => false,
-      :system   => "1.3.7",
+      :force => false,
+      :system => "1.3.7",
     }
 
     assert_equal expected, @cmd.options
@@ -698,11 +700,11 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_update_gem_prerelease
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', '1.a'
-      fetcher.gem  'a', '1.b'
+      fetcher.spec "a", "1.a"
+      fetcher.gem  "a", "1.b"
     end
 
-    @cmd.update_gem 'a', Gem::Requirement.new('= 1.b')
+    @cmd.update_gem "a", Gem::Requirement.new("= 1.b")
 
     refute_empty @cmd.updated
 
@@ -711,15 +713,15 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
   def test_update_gem_unresolved_dependency
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 1
-      fetcher.gem  'a', 2 do |s|
-        s.add_dependency 'b', '>= 2'
+      fetcher.spec "a", 1
+      fetcher.gem  "a", 2 do |s|
+        s.add_dependency "b", ">= 2"
       end
 
-      fetcher.spec 'b', 1
+      fetcher.spec "b", 1
     end
 
-    @cmd.update_gem 'a'
+    @cmd.update_gem "a"
 
     assert_empty @cmd.updated
   end
@@ -729,18 +731,18 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
 
     arguments = @cmd.update_rubygems_arguments
 
-    assert_equal '--prefix',           arguments.shift
+    assert_equal "--prefix",           arguments.shift
     assert_equal Gem.prefix,           arguments.shift
-    assert_equal '--no-document',      arguments.shift
-    assert_equal '--previous-version', arguments.shift
+    assert_equal "--no-document",      arguments.shift
+    assert_equal "--previous-version", arguments.shift
     assert_equal Gem::VERSION,         arguments.shift
     assert_empty arguments
   end
 
   def test_explain
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
-      fetcher.spec 'a', 1
+      fetcher.download "a", 2
+      fetcher.spec "a", 1
     end
 
     @cmd.options[:explain] = true
@@ -760,13 +762,13 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
   def test_explain_platform_local
     local = Gem::Platform.local
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
+      fetcher.download "a", 2
 
-      fetcher.download 'a', 2 do |s|
+      fetcher.download "a", 2 do |s|
         s.platform = local
       end
 
-      fetcher.spec 'a', 1
+      fetcher.spec "a", 1
     end
 
     @cmd.options[:explain] = true
@@ -786,13 +788,13 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
   def test_explain_platform_ruby
     local = Gem::Platform.local
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
+      fetcher.download "a", 2
 
-      fetcher.download 'a', 2 do |s|
+      fetcher.download "a", 2 do |s|
         s.platform = local
       end
 
-      fetcher.spec 'a', 1
+      fetcher.spec "a", 1
     end
 
     # equivalent to --platform=ruby
@@ -811,4 +813,24 @@ class TestGemCommandsUpdateCommand < Gem::TestCase
     assert_equal "  a-2", out.shift
     assert_empty out
   end
+
+  def test_execute_named_not_installed_and_no_update
+    spec_fetcher do |fetcher|
+      fetcher.spec "a", 2
+    end
+
+    @cmd.options[:args] = %w[a b]
+
+    use_ui @ui do
+      @cmd.execute
+    end
+
+    out = @ui.output.split "\n"
+    assert_equal "Updating installed gems", out.shift
+    assert_equal "Nothing to update", out.shift
+    assert_equal "Gems already up-to-date: a", out.shift
+    assert_equal "Gems not currently installed: b", out.shift
+
+    assert_empty out
+  end
 end
