@@ -1,38 +1,37 @@
 # frozen_string_literal: true
-require_relative 'helper'
-require 'rubygems/ext'
-require 'rubygems/installer'
+
+require_relative "helper"
+require "rubygems/ext"
+require "rubygems/installer"
 
 class TestGemExtBuilder < Gem::TestCase
   def setup
+    @orig_DESTDIR = ENV["DESTDIR"]
+    @orig_make = ENV["make"]
     super
 
-    @ext = File.join @tempdir, 'ext'
-    @dest_path = File.join @tempdir, 'prefix'
+    @ext = File.join @tempdir, "ext"
+    @dest_path = File.join @tempdir, "prefix"
 
     FileUtils.mkdir_p @ext
     FileUtils.mkdir_p @dest_path
 
-    @orig_DESTDIR = ENV['DESTDIR']
-    @orig_make = ENV['make']
+    @spec = util_spec "a"
 
-    @spec = util_spec 'a'
-
-    @builder = Gem::Ext::Builder.new @spec, ''
+    @builder = Gem::Ext::Builder.new @spec, ""
   end
 
   def teardown
-    ENV['DESTDIR'] = @orig_DESTDIR
-    ENV['make'] = @orig_make
-
     super
+    ENV["DESTDIR"] = @orig_DESTDIR
+    ENV["make"] = @orig_make
   end
 
   def test_class_make
-    ENV['DESTDIR'] = 'destination'
+    ENV["DESTDIR"] = "destination"
     results = []
 
-    File.open File.join(@ext, 'Makefile'), 'w' do |io|
+    File.open File.join(@ext, "Makefile"), "w" do |io|
       io.puts <<-MAKEFILE
 all:
 \t@#{Gem.ruby} -e "puts %Q{all: \#{ENV['DESTDIR']}}"
@@ -61,10 +60,10 @@ install:
   end
 
   def test_class_make_no_clean
-    ENV['DESTDIR'] = 'destination'
+    ENV["DESTDIR"] = "destination"
     results = []
 
-    File.open File.join(@ext, 'Makefile'), 'w' do |io|
+    File.open File.join(@ext, "Makefile"), "w" do |io|
       io.puts <<-MAKEFILE
 all:
 \t@#{Gem.ruby} -e "puts %Q{all: \#{ENV['DESTDIR']}}"
@@ -84,9 +83,9 @@ install:
   end
 
   def test_custom_make_with_options
-    ENV['make'] = 'make V=1'
+    ENV["make"] = "make V=1"
     results = []
-    File.open File.join(@ext, 'Makefile'), 'w' do |io|
+    File.open File.join(@ext, "Makefile"), "w" do |io|
       io.puts <<-MAKEFILE
 all:
 \t@#{Gem.ruby} -e "puts 'all: OK'"
@@ -106,16 +105,16 @@ install:
   end
 
   def test_build_extensions
-    pend if /mswin/ =~ RUBY_PLATFORM && ENV.key?('GITHUB_ACTIONS') # not working from the beginning
-    @spec.extensions << 'ext/extconf.rb'
+    pend "terminates on mswin" if vc_windows? && ruby_repo?
+    @spec.extensions << "ext/extconf.rb"
 
-    ext_dir = File.join @spec.gem_dir, 'ext'
+    ext_dir = File.join @spec.gem_dir, "ext"
 
     FileUtils.mkdir_p ext_dir
 
-    extconf_rb = File.join ext_dir, 'extconf.rb'
+    extconf_rb = File.join ext_dir, "extconf.rb"
 
-    File.open extconf_rb, 'w' do |f|
+    File.open extconf_rb, "w" do |f|
       f.write <<-'RUBY'
         require 'mkmf'
 
@@ -123,11 +122,11 @@ install:
       RUBY
     end
 
-    ext_lib_dir = File.join ext_dir, 'lib'
+    ext_lib_dir = File.join ext_dir, "lib"
     FileUtils.mkdir ext_lib_dir
-    FileUtils.touch File.join ext_lib_dir, 'a.rb'
-    FileUtils.mkdir File.join ext_lib_dir, 'a'
-    FileUtils.touch File.join ext_lib_dir, 'a', 'b.rb'
+    FileUtils.touch File.join ext_lib_dir, "a.rb"
+    FileUtils.mkdir File.join ext_lib_dir, "a"
+    FileUtils.touch File.join ext_lib_dir, "a", "b.rb"
 
     use_ui @ui do
       @builder.build_extensions
@@ -135,20 +134,20 @@ install:
 
     assert_path_exist @spec.extension_dir
     assert_path_exist @spec.gem_build_complete_path
-    assert_path_exist File.join @spec.extension_dir, 'gem_make.out'
-    assert_path_exist File.join @spec.extension_dir, 'a.rb'
-    assert_path_exist File.join @spec.gem_dir, 'lib', 'a.rb'
-    assert_path_exist File.join @spec.gem_dir, 'lib', 'a', 'b.rb'
+    assert_path_exist File.join @spec.extension_dir, "gem_make.out"
+    assert_path_exist File.join @spec.extension_dir, "a.rb"
+    assert_path_exist File.join @spec.gem_dir, "lib", "a.rb"
+    assert_path_exist File.join @spec.gem_dir, "lib", "a", "b.rb"
   end
 
   def test_build_extensions_with_gemhome_with_space
-    pend if /mswin/ =~ RUBY_PLATFORM && ENV.key?('GITHUB_ACTIONS') # not working from the beginning
-    new_gemhome = File.join @tempdir, 'gem home'
+    pend "terminates on mswin" if vc_windows? && ruby_repo?
+    new_gemhome = File.join @tempdir, "gem home"
     File.rename(@gemhome, new_gemhome)
     @gemhome = new_gemhome
     Gem.use_paths(@gemhome)
-    @spec = util_spec 'a'
-    @builder = Gem::Ext::Builder.new @spec, ''
+    @spec = util_spec "a"
+    @builder = Gem::Ext::Builder.new @spec, ""
 
     test_build_extensions
   end
@@ -163,17 +162,17 @@ install:
         false
       end
     end
-    pend if /mswin/ =~ RUBY_PLATFORM && ENV.key?('GITHUB_ACTIONS') # not working from the beginning
+    pend "terminates on mswin" if vc_windows? && ruby_repo?
 
-    @spec.extensions << 'ext/extconf.rb'
+    @spec.extensions << "ext/extconf.rb"
 
-    ext_dir = File.join @spec.gem_dir, 'ext'
+    ext_dir = File.join @spec.gem_dir, "ext"
 
     FileUtils.mkdir_p ext_dir
 
-    extconf_rb = File.join ext_dir, 'extconf.rb'
+    extconf_rb = File.join ext_dir, "extconf.rb"
 
-    File.open extconf_rb, 'w' do |f|
+    File.open extconf_rb, "w" do |f|
       f.write <<-'RUBY'
         require 'mkmf'
 
@@ -181,11 +180,11 @@ install:
       RUBY
     end
 
-    ext_lib_dir = File.join ext_dir, 'lib'
+    ext_lib_dir = File.join ext_dir, "lib"
     FileUtils.mkdir ext_lib_dir
-    FileUtils.touch File.join ext_lib_dir, 'a.rb'
-    FileUtils.mkdir File.join ext_lib_dir, 'a'
-    FileUtils.touch File.join ext_lib_dir, 'a', 'b.rb'
+    FileUtils.touch File.join ext_lib_dir, "a.rb"
+    FileUtils.mkdir File.join ext_lib_dir, "a"
+    FileUtils.touch File.join ext_lib_dir, "a", "b.rb"
 
     use_ui @ui do
       @builder.build_extensions
@@ -193,10 +192,10 @@ install:
 
     assert_path_exist @spec.extension_dir
     assert_path_exist @spec.gem_build_complete_path
-    assert_path_exist File.join @spec.extension_dir, 'gem_make.out'
-    assert_path_exist File.join @spec.extension_dir, 'a.rb'
-    assert_path_not_exist File.join @spec.gem_dir, 'lib', 'a.rb'
-    assert_path_not_exist File.join @spec.gem_dir, 'lib', 'a', 'b.rb'
+    assert_path_exist File.join @spec.extension_dir, "gem_make.out"
+    assert_path_exist File.join @spec.extension_dir, "a.rb"
+    assert_path_not_exist File.join @spec.gem_dir, "lib", "a.rb"
+    assert_path_not_exist File.join @spec.gem_dir, "lib", "a", "b.rb"
   ensure
     class << Gem
       remove_method :install_extension_in_lib
@@ -210,10 +209,10 @@ install:
       @builder.build_extensions
     end
 
-    assert_equal '', @ui.output
-    assert_equal '', @ui.error
+    assert_equal "", @ui.output
+    assert_equal "", @ui.error
 
-    assert_path_not_exist File.join @spec.extension_dir, 'gem_make.out'
+    assert_path_not_exist File.join @spec.extension_dir, "gem_make.out"
   end
 
   def test_build_extensions_rebuild_failure
@@ -234,7 +233,7 @@ install:
   def test_build_extensions_extconf_bad
     cwd = Dir.pwd
 
-    @spec.extensions << 'extconf.rb'
+    @spec.extensions << "extconf.rb"
 
     FileUtils.mkdir_p @spec.gem_dir
 
@@ -246,9 +245,9 @@ install:
 
     assert_match(/\AERROR: Failed to build gem native extension.$/, e.message)
     assert_equal "Building native extensions. This could take a while...\n", @ui.output
-    assert_equal '', @ui.error
+    assert_equal "", @ui.error
 
-    gem_make_out = File.join @spec.extension_dir, 'gem_make.out'
+    gem_make_out = File.join @spec.extension_dir, "gem_make.out"
     cmd_make_out = File.read(gem_make_out)
 
     assert_match %r{#{Regexp.escape Gem.ruby} .* extconf\.rb}, cmd_make_out
@@ -261,7 +260,7 @@ install:
 
   def test_build_extensions_unsupported
     FileUtils.mkdir_p @spec.gem_dir
-    gem_make_out = File.join @spec.extension_dir, 'gem_make.out'
+    gem_make_out = File.join @spec.extension_dir, "gem_make.out"
     @spec.extensions << nil
 
     e = assert_raise Gem::Ext::BuildError do
@@ -272,7 +271,7 @@ install:
 
     assert_match(/^\s*No builder for extension ''$/, e.message)
     assert_equal "Building native extensions. This could take a while...\n", @ui.output
-    assert_equal '', @ui.error
+    assert_equal "", @ui.error
 
     assert_equal "No builder for extension ''\n", File.read(gem_make_out)
 
@@ -284,7 +283,7 @@ install:
   def test_build_extensions_with_build_args
     args = ["--aa", "--bb"]
     @builder.build_args = args
-    @spec.extensions << 'extconf.rb'
+    @spec.extensions << "extconf.rb"
 
     FileUtils.mkdir_p @spec.gem_dir
 
@@ -315,14 +314,14 @@ install:
   end
 
   def test_initialize
-    build_info_dir = File.join @gemhome, 'build_info'
+    build_info_dir = File.join @gemhome, "build_info"
 
     FileUtils.mkdir_p build_info_dir
 
     build_info_file = File.join build_info_dir, "#{@spec.full_name}.info"
 
-    File.open build_info_file, 'w' do |io|
-      io.puts '--with-foo-dir=/nonexistent'
+    File.open build_info_file, "w" do |io|
+      io.puts "--with-foo-dir=/nonexistent"
     end
 
     builder = Gem::Ext::Builder.new @spec
