@@ -1,6 +1,7 @@
 # frozen_string_literal: true
-require_relative 'helper'
-require 'rubygems/ext'
+
+require_relative "helper"
+require "rubygems/ext"
 
 class TestGemExtCmakeBuilder < Gem::TestCase
   def setup
@@ -12,21 +13,21 @@ class TestGemExtCmakeBuilder < Gem::TestCase
     require "open3"
 
     begin
-      _, status = Open3.capture2e('cmake')
-      pend 'cmake not present' unless status.success?
+      _, status = Open3.capture2e("cmake")
+      pend "cmake not present" unless status.success?
     rescue Errno::ENOENT
-      pend 'cmake not present'
+      pend "cmake not present"
     end
 
-    @ext = File.join @tempdir, 'ext'
-    @dest_path = File.join @tempdir, 'prefix'
+    @ext = File.join @tempdir, "ext"
+    @dest_path = File.join @tempdir, "prefix"
 
     FileUtils.mkdir_p @ext
     FileUtils.mkdir_p @dest_path
   end
 
   def test_self_build
-    File.open File.join(@ext, 'CMakeLists.txt'), 'w' do |cmakelists|
+    File.open File.join(@ext, "CMakeLists.txt"), "w" do |cmakelists|
       cmakelists.write <<-EO_CMAKE
 cmake_minimum_required(VERSION 2.6)
 project(self_build NONE)
@@ -34,7 +35,7 @@ install (FILES test.txt DESTINATION bin)
       EO_CMAKE
     end
 
-    FileUtils.touch File.join(@ext, 'test.txt')
+    FileUtils.touch File.join(@ext, "test.txt")
 
     output = []
 
@@ -44,8 +45,8 @@ install (FILES test.txt DESTINATION bin)
 
     assert_match %r{^cmake \. -DCMAKE_INSTALL_PREFIX\\=#{Regexp.escape @dest_path}}, output
     assert_match %r{#{Regexp.escape @ext}}, output
-    assert_contains_make_command '', output
-    assert_contains_make_command 'install', output
+    assert_contains_make_command "", output
+    assert_contains_make_command "install", output
     assert_match %r{test\.txt}, output
   end
 
@@ -60,14 +61,14 @@ install (FILES test.txt DESTINATION bin)
 
     shell_error_msg = %r{(CMake Error: .*)}
 
-    assert_match 'cmake failed', error.message
+    assert_match "cmake failed", error.message
 
     assert_match %r{^cmake . -DCMAKE_INSTALL_PREFIX\\=#{Regexp.escape @dest_path}}, output
     assert_match %r{#{shell_error_msg}}, output
   end
 
   def test_self_build_has_makefile
-    File.open File.join(@ext, 'Makefile'), 'w' do |makefile|
+    File.open File.join(@ext, "Makefile"), "w" do |makefile|
       makefile.puts "all:\n\t@echo ok\ninstall:\n\t@echo ok"
     end
 
@@ -77,7 +78,7 @@ install (FILES test.txt DESTINATION bin)
 
     output = output.join "\n"
 
-    assert_contains_make_command '', output
-    assert_contains_make_command 'install', output
+    assert_contains_make_command "", output
+    assert_contains_make_command "install", output
   end
 end
