@@ -1,16 +1,16 @@
 # frozen_string_literal: true
-require 'rubygems/test_case'
 
-require 'webrick'
-require 'webrick/https' if Gem::HAVE_OPENSSL
+require_relative "helper"
+
+require "webrick"
+require "webrick/https" if Gem::HAVE_OPENSSL
 
 unless Gem::HAVE_OPENSSL
-  warn 'Skipping Gem::RemoteFetcher tests.  openssl not found.'
+  warn "Skipping Gem::RemoteFetcher tests.  openssl not found."
 end
 
-require 'rubygems/remote_fetcher'
-require 'rubygems/package'
-require 'minitest/mock'
+require "rubygems/remote_fetcher"
+require "rubygems/package"
 
 # = Testing Proxy Settings
 #
@@ -29,7 +29,7 @@ require 'minitest/mock'
 class TestGemRemoteFetcher < Gem::TestCase
   include Gem::DefaultUserInteraction
 
-  SERVER_DATA = <<-EOY.freeze
+  SERVER_DATA = <<-EOY
 --- !ruby/object:Gem::Cache
 gems:
   rake-0.4.11: !ruby/object:Gem::Specification
@@ -70,7 +70,7 @@ gems:
     dependencies: []
   EOY
 
-  PROXY_DATA = SERVER_DATA.gsub(/0.4.11/, '0.4.2')
+  PROXY_DATA = SERVER_DATA.gsub(/0.4.11/, "0.4.2")
 
   # Generated via:
   #   x = OpenSSL::PKey::DH.new(2048) # wait a while...
@@ -105,11 +105,11 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     @cache_dir = File.join @gemhome, "cache"
 
     # TODO: why does the remote fetcher need it written to disk?
-    @a1, @a1_gem = util_gem 'a', '1' do |s|
-      s.executables << 'a_bin'
+    @a1, @a1_gem = util_gem "a", "1" do |s|
+      s.executables << "a_bin"
     end
 
-    @a1.loaded_from = File.join(@gemhome, 'specifications', @a1.full_name)
+    @a1.loaded_from = File.join(@gemhome, "specifications", @a1.full_name)
 
     Gem::RemoteFetcher.fetcher = nil
     @stub_ui = Gem::MockGemUi.new
@@ -131,7 +131,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   end
 
   def test_self_fetcher_with_proxy
-    proxy_uri = 'http://proxy.example.com'
+    proxy_uri = "http://proxy.example.com"
     Gem.configuration[:http_proxy] = proxy_uri
     Gem::RemoteFetcher.fetcher = nil
 
@@ -146,45 +146,60 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
 
-    e = assert_raises ArgumentError do
+    e = assert_raise ArgumentError do
       @fetcher.fetch_path("gems.example.com/yaml", nil, true)
     end
 
-    assert_equal 'uri scheme is invalid: nil', e.message
+    assert_equal "uri scheme is invalid: nil", e.message
   end
 
   def test_no_proxy
     use_ui @stub_ui do
       assert_data_from_server @fetcher.fetch_path(@server_uri)
       response = @fetcher.fetch_path(@server_uri, nil, true)
-      assert_equal SERVER_DATA.size, response['content-length'].to_i
+      assert_equal SERVER_DATA.size, response["content-length"].to_i
     end
   end
 
   def test_cache_update_path
-    uri = URI 'http://example/file'
-    path = File.join @tempdir, 'file'
+    uri = URI "http://example/file"
+    path = File.join @tempdir, "file"
 
-    fetcher = util_fuck_with_fetcher 'hello'
+    fetcher = util_fuck_with_fetcher "hello"
 
     data = fetcher.cache_update_path uri, path
 
-    assert_equal 'hello', data
+    assert_equal "hello", data
 
-    assert_equal 'hello', File.read(path)
+    assert_equal "hello", File.read(path)
+  end
+
+  def test_cache_update_path_with_utf8_internal_encoding
+    with_internal_encoding("UTF-8") do
+      uri = URI "http://example/file"
+      path = File.join @tempdir, "file"
+      data = String.new("\xC8").force_encoding(Encoding::BINARY)
+
+      fetcher = util_fuck_with_fetcher data
+
+      written_data = fetcher.cache_update_path uri, path
+
+      assert_equal data, written_data
+      assert_equal data, File.binread(path)
+    end
   end
 
   def test_cache_update_path_no_update
-    uri = URI 'http://example/file'
-    path = File.join @tempdir, 'file'
+    uri = URI "http://example/file"
+    path = File.join @tempdir, "file"
 
-    fetcher = util_fuck_with_fetcher 'hello'
+    fetcher = util_fuck_with_fetcher "hello"
 
     data = fetcher.cache_update_path uri, path, false
 
-    assert_equal 'hello', data
+    assert_equal "hello", data
 
-    refute_path_exists path
+    assert_path_not_exist path
   end
 
   def util_fuck_with_fetcher(data, blow = false)
@@ -205,7 +220,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
           @test_data
         end
 
-        raise Gem::RemoteFetcher::FetchError.new("haha!", '')
+        raise Gem::RemoteFetcher::FetchError.new("haha!", "")
       end
     end
 
@@ -214,14 +229,14 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_download
     a1_data = nil
-    File.open @a1_gem, 'rb' do |fp|
+    File.open @a1_gem, "rb" do |fp|
       a1_data = fp.read
     end
 
     fetcher = util_fuck_with_fetcher a1_data
 
     a1_cache_gem = @a1.cache_file
-    assert_equal a1_cache_gem, fetcher.download(@a1, 'http://gems.example.com')
+    assert_equal a1_cache_gem, fetcher.download(@a1, "http://gems.example.com")
     assert_equal("http://gems.example.com/gems/a-1.gem",
                  fetcher.instance_variable_get(:@test_arg).to_s)
     assert File.exist?(a1_cache_gem)
@@ -229,29 +244,59 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_download_with_auth
     a1_data = nil
-    File.open @a1_gem, 'rb' do |fp|
+    File.open @a1_gem, "rb" do |fp|
       a1_data = fp.read
     end
 
     fetcher = util_fuck_with_fetcher a1_data
 
     a1_cache_gem = @a1.cache_file
-    assert_equal a1_cache_gem, fetcher.download(@a1, 'http://user:password@gems.example.com')
+    assert_equal a1_cache_gem, fetcher.download(@a1, "http://user:password@gems.example.com")
     assert_equal("http://user:password@gems.example.com/gems/a-1.gem",
                  fetcher.instance_variable_get(:@test_arg).to_s)
     assert File.exist?(a1_cache_gem)
   end
 
+  def test_download_with_token
+    a1_data = nil
+    File.open @a1_gem, "rb" do |fp|
+      a1_data = fp.read
+    end
+
+    fetcher = util_fuck_with_fetcher a1_data
+
+    a1_cache_gem = @a1.cache_file
+    assert_equal a1_cache_gem, fetcher.download(@a1, "http://token@gems.example.com")
+    assert_equal("http://token@gems.example.com/gems/a-1.gem",
+                 fetcher.instance_variable_get(:@test_arg).to_s)
+    assert File.exist?(a1_cache_gem)
+  end
+
+  def test_download_with_x_oauth_basic
+    a1_data = nil
+    File.open @a1_gem, "rb" do |fp|
+      a1_data = fp.read
+    end
+
+    fetcher = util_fuck_with_fetcher a1_data
+
+    a1_cache_gem = @a1.cache_file
+    assert_equal a1_cache_gem, fetcher.download(@a1, "http://token:x-oauth-basic@gems.example.com")
+    assert_equal("http://token:x-oauth-basic@gems.example.com/gems/a-1.gem",
+                 fetcher.instance_variable_get(:@test_arg).to_s)
+    assert File.exist?(a1_cache_gem)
+  end
+
   def test_download_with_encoded_auth
     a1_data = nil
-    File.open @a1_gem, 'rb' do |fp|
+    File.open @a1_gem, "rb" do |fp|
       a1_data = fp.read
     end
 
     fetcher = util_fuck_with_fetcher a1_data
 
     a1_cache_gem = @a1.cache_file
-    assert_equal a1_cache_gem, fetcher.download(@a1, 'http://user:%25pas%25sword@gems.example.com')
+    assert_equal a1_cache_gem, fetcher.download(@a1, "http://user:%25pas%25sword@gems.example.com")
     assert_equal("http://user:%25pas%25sword@gems.example.com/gems/a-1.gem",
                  fetcher.instance_variable_get(:@test_arg).to_s)
     assert File.exist?(a1_cache_gem)
@@ -262,7 +307,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
     inst = Gem::RemoteFetcher.fetcher
 
-    assert_equal @a1.cache_file, inst.download(@a1, 'http://gems.example.com')
+    assert_equal @a1.cache_file, inst.download(@a1, "http://gems.example.com")
   end
 
   def test_download_local
@@ -278,7 +323,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   end
 
   def test_download_local_space
-    space_path = File.join @tempdir, 'space path'
+    space_path = File.join @tempdir, "space path"
     FileUtils.mkdir space_path
     FileUtils.mv @a1_gem, space_path
     local_path = File.join space_path, @a1.file_name
@@ -292,17 +337,17 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   end
 
   def test_download_install_dir
-    a1_data = File.open @a1_gem, 'rb' do |fp|
+    a1_data = File.open @a1_gem, "rb" do |fp|
       fp.read
     end
 
     fetcher = util_fuck_with_fetcher a1_data
 
-    install_dir = File.join @tempdir, 'more_gems'
+    install_dir = File.join @tempdir, "more_gems"
 
     a1_cache_gem = File.join install_dir, "cache", @a1.file_name
     FileUtils.mkdir_p(File.dirname(a1_cache_gem))
-    actual = fetcher.download(@a1, 'http://gems.example.com', install_dir)
+    actual = fetcher.download(@a1, "http://gems.example.com", install_dir)
 
     assert_equal a1_cache_gem, actual
     assert_equal("http://gems.example.com/gems/a-1.gem",
@@ -336,7 +381,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       FileUtils.chmod 0555, @gemhome
 
       fetcher = util_fuck_with_fetcher File.read(@a1_gem)
-      fetcher.download(@a1, 'http://gems.example.com')
+      fetcher.download(@a1, "http://gems.example.com")
       a1_cache_gem = File.join Gem.user_dir, "cache", @a1.file_name
       assert File.exist? a1_cache_gem
     ensure
@@ -346,16 +391,16 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   end
 
   def test_download_platform_legacy
-    original_platform = 'old-platform'
+    original_platform = "old-platform"
 
-    e1, e1_gem = util_gem 'e', '1' do |s|
+    e1, e1_gem = util_gem "e", "1" do |s|
       s.platform = Gem::Platform::CURRENT
       s.instance_variable_set :@original_platform, original_platform
     end
-    e1.loaded_from = File.join(@gemhome, 'specifications', e1.full_name)
+    e1.loaded_from = File.join(@gemhome, "specifications", e1.full_name)
 
     e1_data = nil
-    File.open e1_gem, 'rb' do |fp|
+    File.open e1_gem, "rb" do |fp|
       e1_data = fp.read
     end
 
@@ -363,7 +408,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
     e1_cache_gem = e1.cache_file
 
-    assert_equal e1_cache_gem, fetcher.download(e1, 'http://gems.example.com')
+    assert_equal e1_cache_gem, fetcher.download(e1, "http://gems.example.com")
 
     assert_equal("http://gems.example.com/gems/#{e1.original_name}.gem",
                  fetcher.instance_variable_get(:@test_arg).to_s)
@@ -390,15 +435,15 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_download_unsupported
     inst = Gem::RemoteFetcher.fetcher
 
-    e = assert_raises ArgumentError do
-      inst.download @a1, 'ftp://gems.rubyforge.org'
+    e = assert_raise ArgumentError do
+      inst.download @a1, "ftp://gems.rubyforge.org"
     end
 
-    assert_equal 'unsupported URI scheme ftp', e.message
+    assert_equal "unsupported URI scheme ftp", e.message
   end
 
   def test_download_to_cache
-    @a2, @a2_gem = util_gem 'a', '2'
+    @a2, @a2_gem = util_gem "a", "2"
 
     util_setup_spec_fetcher @a1, @a2
     @fetcher.instance_variable_set :@a1, @a1
@@ -414,7 +459,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       end
     end
 
-    gem = Gem::RemoteFetcher.fetcher.download_to_cache dep 'a'
+    gem = Gem::RemoteFetcher.fetcher.download_to_cache dep "a"
 
     assert_equal @a2.file_name, File.basename(gem)
   end
@@ -424,10 +469,10 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     @fetcher = fetcher
 
     def fetcher.fetch_http(uri, mtime, head = nil)
-      Gem::Util.gzip 'foo'
+      Gem::Util.gzip "foo"
     end
 
-    assert_equal 'foo', fetcher.fetch_path(@uri + 'foo.gz')
+    assert_equal "foo", fetcher.fetch_path(@uri + "foo.gz")
   end
 
   def test_fetch_path_gzip_unmodified
@@ -438,7 +483,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       nil
     end
 
-    assert_nil fetcher.fetch_path(@uri + 'foo.gz', Time.at(0))
+    assert_nil fetcher.fetch_path(@uri + "foo.gz", Time.at(0))
   end
 
   def test_fetch_path_io_error
@@ -449,9 +494,9 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       raise EOFError
     end
 
-    url = 'http://example.com/uri'
+    url = "http://example.com/uri"
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_path url
     end
 
@@ -467,9 +512,9 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       raise SocketError
     end
 
-    url = 'http://example.com/uri'
+    url = "http://example.com/uri"
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_path url
     end
 
@@ -482,12 +527,12 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     @fetcher = fetcher
 
     def fetcher.fetch_http(uri, mtime = nil, head = nil)
-      raise Errno::ECONNREFUSED, 'connect(2)'
+      raise Errno::ECONNREFUSED, "connect(2)"
     end
 
-    url = 'http://example.com/uri'
+    url = "http://example.com/uri"
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_path url
     end
 
@@ -496,6 +541,44 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     assert_equal url, e.uri
   end
 
+  def test_fetch_path_timeout_error
+    fetcher = Gem::RemoteFetcher.new nil
+    @fetcher = fetcher
+
+    def fetcher.fetch_http(uri, mtime = nil, head = nil)
+      raise Timeout::Error, "timed out"
+    end
+
+    url = "http://example.com/uri"
+
+    e = assert_raise Gem::RemoteFetcher::FetchError do
+      fetcher.fetch_path url
+    end
+
+    assert_match %r{Timeout::Error: timed out \(#{Regexp.escape url}\)\z},
+                 e.message
+    assert_equal url, e.uri
+  end
+
+  def test_fetch_path_getaddrinfo_error
+    fetcher = Gem::RemoteFetcher.new nil
+    @fetcher = fetcher
+
+    def fetcher.fetch_http(uri, mtime = nil, head = nil)
+      raise SocketError, "getaddrinfo: nodename nor servname provided"
+    end
+
+    url = "http://example.com/uri"
+
+    e = assert_raise Gem::RemoteFetcher::FetchError do
+      fetcher.fetch_path url
+    end
+
+    assert_match %r{SocketError: getaddrinfo: nodename nor servname provided \(#{Regexp.escape url}\)\z},
+                 e.message
+    assert_equal url, e.uri
+  end
+
   def test_fetch_path_openssl_ssl_sslerror
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
@@ -504,9 +587,9 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       raise OpenSSL::SSL::SSLError
     end
 
-    url = 'http://example.com/uri'
+    url = "http://example.com/uri"
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_path url
     end
 
@@ -527,7 +610,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_implicit_no_proxy
     use_ui @stub_ui do
-      ENV['http_proxy'] = 'http://fakeurl:12345'
+      ENV["http_proxy"] = "http://fakeurl:12345"
       fetcher = Gem::RemoteFetcher.new :no_proxy
       @fetcher = fetcher
       assert_data_from_server fetcher.fetch_path(@server_uri)
@@ -536,7 +619,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_implicit_proxy
     use_ui @stub_ui do
-      ENV['http_proxy'] = @proxy_uri
+      ENV["http_proxy"] = @proxy_uri
       fetcher = Gem::RemoteFetcher.new nil
       @fetcher = fetcher
       assert_data_from_proxy fetcher.fetch_path(@server_uri)
@@ -545,7 +628,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_implicit_upper_case_proxy
     use_ui @stub_ui do
-      ENV['HTTP_PROXY'] = @proxy_uri
+      ENV["HTTP_PROXY"] = @proxy_uri
       fetcher = Gem::RemoteFetcher.new nil
       @fetcher = fetcher
       assert_data_from_proxy fetcher.fetch_path(@server_uri)
@@ -563,40 +646,40 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_fetch_http
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
-    url = 'http://gems.example.com/redirect'
+    url = "http://gems.example.com/redirect"
 
     def fetcher.request(uri, request_class, last_modified = nil)
-      url = 'http://gems.example.com/redirect'
+      url = "http://gems.example.com/redirect"
       unless defined? @requested
         @requested = true
         res = Net::HTTPMovedPermanently.new nil, 301, nil
-        res.add_field 'Location', url
+        res.add_field "Location", url
         res
       else
         res = Net::HTTPOK.new nil, 200, nil
-        def res.body() 'real_path' end
+        def res.body() "real_path" end
         res
       end
     end
 
     data = fetcher.fetch_http URI.parse(url)
 
-    assert_equal 'real_path', data
+    assert_equal "real_path", data
   end
 
   def test_fetch_http_redirects
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
-    url = 'http://gems.example.com/redirect'
+    url = "http://gems.example.com/redirect"
 
     def fetcher.request(uri, request_class, last_modified = nil)
-      url = 'http://gems.example.com/redirect'
+      url = "http://gems.example.com/redirect"
       res = Net::HTTPMovedPermanently.new nil, 301, nil
-      res.add_field 'Location', url
+      res.add_field "Location", url
       res
     end
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_http URI.parse(url)
     end
 
@@ -606,14 +689,14 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_fetch_http_redirects_without_location
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
-    url = 'http://gems.example.com/redirect'
+    url = "http://gems.example.com/redirect"
 
     def fetcher.request(uri, request_class, last_modified = nil)
       res = Net::HTTPMovedPermanently.new nil, 301, nil
       res
     end
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_http URI.parse(url)
     end
 
@@ -623,12 +706,12 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_fetch_http_with_additional_headers
     ENV["http_proxy"] = @proxy_uri
     ENV["no_proxy"] = URI::parse(@server_uri).host
-    fetcher = Gem::RemoteFetcher.new nil, nil, {"X-Captain" => "murphy"}
+    fetcher = Gem::RemoteFetcher.new nil, nil, { "X-Captain" => "murphy" }
     @fetcher = fetcher
     assert_equal "murphy", fetcher.fetch_path(@server_uri)
   end
 
-  def assert_fetch_s3(url, signature, token=nil, region='us-east-1', instance_profile_json=nil)
+  def assert_fetch_s3(url, signature, token=nil, region="us-east-1", instance_profile_json=nil)
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
     $fetched_uri = nil
@@ -637,12 +720,12 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     def fetcher.request(uri, request_class, last_modified = nil)
       $fetched_uri = uri
       res = Net::HTTPOK.new nil, 200, nil
-      def res.body() 'success' end
+      def res.body() "success" end
       res
     end
 
     def fetcher.s3_uri_signer(uri)
-      require 'json'
+      require "json"
       s3_uri_signer = Gem::S3URISigner.new(uri)
       def s3_uri_signer.ec2_metadata_credentials_json
         JSON.parse($instance_profile)
@@ -656,18 +739,18 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     data = fetcher.fetch_s3 URI.parse(url)
 
     assert_equal "https://my-bucket.s3.#{region}.amazonaws.com/gems/specs.4.8.gz?X-Amz-Algorithm=AWS4-HMAC-SHA256&X-Amz-Credential=testuser%2F20190624%2F#{region}%2Fs3%2Faws4_request&X-Amz-Date=20190624T050641Z&X-Amz-Expires=86400#{token ? "&X-Amz-Security-Token=" + token : ""}&X-Amz-SignedHeaders=host&X-Amz-Signature=#{signature}", $fetched_uri.to_s
-    assert_equal 'success', data
+    assert_equal "success", data
   ensure
     $fetched_uri = nil
   end
 
   def test_fetch_s3_config_creds
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:id => 'testuser', :secret => 'testpass'},
+      "my-bucket" => { :id => "testuser", :secret => "testpass" },
     }
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b"
     end
   ensure
     Gem.configuration[:s3_source] = nil
@@ -675,11 +758,11 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_fetch_s3_config_creds_with_region
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:id => 'testuser', :secret => 'testpass', :region => 'us-west-2'},
+      "my-bucket" => { :id => "testuser", :secret => "testpass", :region => "us-west-2" },
     }
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '4afc3010757f1fd143e769f1d1dabd406476a4fc7c120e9884fd02acbb8f26c9', nil, 'us-west-2'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "4afc3010757f1fd143e769f1d1dabd406476a4fc7c120e9884fd02acbb8f26c9", nil, "us-west-2"
     end
   ensure
     Gem.configuration[:s3_source] = nil
@@ -687,79 +770,79 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_fetch_s3_config_creds_with_token
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:id => 'testuser', :secret => 'testpass', :security_token => 'testtoken'},
+      "my-bucket" => { :id => "testuser", :secret => "testpass", :security_token => "testtoken" },
     }
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '935160a427ef97e7630f799232b8f208c4a4e49aad07d0540572a2ad5fe9f93c', 'testtoken'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "935160a427ef97e7630f799232b8f208c4a4e49aad07d0540572a2ad5fe9f93c", "testtoken"
     end
   ensure
     Gem.configuration[:s3_source] = nil
   end
 
   def test_fetch_s3_env_creds
-    ENV['AWS_ACCESS_KEY_ID'] = 'testuser'
-    ENV['AWS_SECRET_ACCESS_KEY'] = 'testpass'
-    ENV['AWS_SESSION_TOKEN'] = nil
+    ENV["AWS_ACCESS_KEY_ID"] = "testuser"
+    ENV["AWS_SECRET_ACCESS_KEY"] = "testpass"
+    ENV["AWS_SESSION_TOKEN"] = nil
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:provider => 'env'},
+      "my-bucket" => { :provider => "env" },
     }
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b"
     end
   ensure
-    ENV.each_key {|key| ENV.delete(key) if key.start_with?('AWS') }
+    ENV.each_key {|key| ENV.delete(key) if key.start_with?("AWS") }
     Gem.configuration[:s3_source] = nil
   end
 
   def test_fetch_s3_env_creds_with_region
-    ENV['AWS_ACCESS_KEY_ID'] = 'testuser'
-    ENV['AWS_SECRET_ACCESS_KEY'] = 'testpass'
-    ENV['AWS_SESSION_TOKEN'] = nil
+    ENV["AWS_ACCESS_KEY_ID"] = "testuser"
+    ENV["AWS_SECRET_ACCESS_KEY"] = "testpass"
+    ENV["AWS_SESSION_TOKEN"] = nil
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:provider => 'env', :region => 'us-west-2'},
+      "my-bucket" => { :provider => "env", :region => "us-west-2" },
     }
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '4afc3010757f1fd143e769f1d1dabd406476a4fc7c120e9884fd02acbb8f26c9', nil, 'us-west-2'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "4afc3010757f1fd143e769f1d1dabd406476a4fc7c120e9884fd02acbb8f26c9", nil, "us-west-2"
     end
   ensure
-    ENV.each_key {|key| ENV.delete(key) if key.start_with?('AWS') }
+    ENV.each_key {|key| ENV.delete(key) if key.start_with?("AWS") }
     Gem.configuration[:s3_source] = nil
   end
 
   def test_fetch_s3_env_creds_with_token
-    ENV['AWS_ACCESS_KEY_ID'] = 'testuser'
-    ENV['AWS_SECRET_ACCESS_KEY'] = 'testpass'
-    ENV['AWS_SESSION_TOKEN'] = 'testtoken'
+    ENV["AWS_ACCESS_KEY_ID"] = "testuser"
+    ENV["AWS_SECRET_ACCESS_KEY"] = "testpass"
+    ENV["AWS_SESSION_TOKEN"] = "testtoken"
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:provider => 'env'},
+      "my-bucket" => { :provider => "env" },
     }
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '935160a427ef97e7630f799232b8f208c4a4e49aad07d0540572a2ad5fe9f93c', 'testtoken'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "935160a427ef97e7630f799232b8f208c4a4e49aad07d0540572a2ad5fe9f93c", "testtoken"
     end
   ensure
-    ENV.each_key {|key| ENV.delete(key) if key.start_with?('AWS') }
+    ENV.each_key {|key| ENV.delete(key) if key.start_with?("AWS") }
     Gem.configuration[:s3_source] = nil
   end
 
   def test_fetch_s3_url_creds
-    url = 's3://testuser:testpass@my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b'
+    url = "s3://testuser:testpass@my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b"
     end
   end
 
   def test_fetch_s3_instance_profile_creds
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:provider => 'instance_profile'},
+      "my-bucket" => { :provider => "instance_profile" },
     }
 
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b', nil, 'us-east-1',
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "20f974027db2f3cd6193565327a7c73457a138efb1a63ea248d185ce6827d41b", nil, "us-east-1",
                       '{"AccessKeyId": "testuser", "SecretAccessKey": "testpass"}'
     end
   ensure
@@ -768,12 +851,12 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_fetch_s3_instance_profile_creds_with_region
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:provider => 'instance_profile', :region => 'us-west-2'},
+      "my-bucket" => { :provider => "instance_profile", :region => "us-west-2" },
     }
 
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '4afc3010757f1fd143e769f1d1dabd406476a4fc7c120e9884fd02acbb8f26c9', nil, 'us-west-2',
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "4afc3010757f1fd143e769f1d1dabd406476a4fc7c120e9884fd02acbb8f26c9", nil, "us-west-2",
                       '{"AccessKeyId": "testuser", "SecretAccessKey": "testpass"}'
     end
   ensure
@@ -782,12 +865,12 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_fetch_s3_instance_profile_creds_with_token
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:provider => 'instance_profile'},
+      "my-bucket" => { :provider => "instance_profile" },
     }
 
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    Time.stub :now, Time.at(1561353581) do
-      assert_fetch_s3 url, '935160a427ef97e7630f799232b8f208c4a4e49aad07d0540572a2ad5fe9f93c', 'testtoken', 'us-east-1',
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    Time.stub :now, Time.at(1_561_353_581) do
+      assert_fetch_s3 url, "935160a427ef97e7630f799232b8f208c4a4e49aad07d0540572a2ad5fe9f93c", "testtoken", "us-east-1",
                       '{"AccessKeyId": "testuser", "SecretAccessKey": "testpass", "Token": "testtoken"}'
     end
   ensure
@@ -798,7 +881,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     fetcher = Gem::RemoteFetcher.new nil
     @fetcher = fetcher
 
-    e = assert_raises Gem::RemoteFetcher::FetchError do
+    e = assert_raise Gem::RemoteFetcher::FetchError do
       fetcher.fetch_s3 URI.parse(url)
     end
 
@@ -806,35 +889,35 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   end
 
   def test_fetch_s3_no_source_key
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    refute_fetch_s3 url, 'no s3_source key exists in .gemrc'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    refute_fetch_s3 url, "no s3_source key exists in .gemrc"
   end
 
   def test_fetch_s3_no_host
     Gem.configuration[:s3_source] = {
-      'my-bucket' => {:id => 'testuser', :secret => 'testpass'},
+      "my-bucket" => { :id => "testuser", :secret => "testpass" },
     }
 
-    url = 's3://other-bucket/gems/specs.4.8.gz'
-    refute_fetch_s3 url, 'no key for host other-bucket in s3_source in .gemrc'
+    url = "s3://other-bucket/gems/specs.4.8.gz"
+    refute_fetch_s3 url, "no key for host other-bucket in s3_source in .gemrc"
   ensure
     Gem.configuration[:s3_source] = nil
   end
 
   def test_fetch_s3_no_id
-    Gem.configuration[:s3_source] = { 'my-bucket' => {:secret => 'testpass'} }
+    Gem.configuration[:s3_source] = { "my-bucket" => { :secret => "testpass" } }
 
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    refute_fetch_s3 url, 's3_source for my-bucket missing id or secret'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    refute_fetch_s3 url, "s3_source for my-bucket missing id or secret"
   ensure
     Gem.configuration[:s3_source] = nil
   end
 
   def test_fetch_s3_no_secret
-    Gem.configuration[:s3_source] = { 'my-bucket' => {:id => 'testuser'} }
+    Gem.configuration[:s3_source] = { "my-bucket" => { :id => "testuser" } }
 
-    url = 's3://my-bucket/gems/specs.4.8.gz'
-    refute_fetch_s3 url, 's3_source for my-bucket missing id or secret'
+    url = "s3://my-bucket/gems/specs.4.8.gz"
+    refute_fetch_s3 url, "s3_source for my-bucket missing id or secret"
   ensure
     Gem.configuration[:s3_source] = nil
   end
@@ -864,7 +947,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     @fetcher = fetcher
 
     assert_throws :block_called do
-      fetcher.request URI('http://example'), Net::HTTP::Get do |req|
+      fetcher.request URI("http://example"), Net::HTTP::Get do |req|
         assert_kind_of Net::HTTPGenericRequest, req
         throw :block_called
       end
@@ -882,7 +965,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_ssl_connection
     ssl_server = start_ssl_server
-    temp_ca_cert = File.join(__dir__, 'ca_cert.pem')
+    temp_ca_cert = File.join(__dir__, "ca_cert.pem")
     with_configured_fetcher(":ssl_ca_cert: #{temp_ca_cert}") do |fetcher|
       fetcher.fetch_path("https://localhost:#{ssl_server.config[:Port]}/yaml")
     end
@@ -891,10 +974,10 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_ssl_client_cert_auth_connection
     ssl_server = start_ssl_server({
       :SSLVerifyClient =>
-        OpenSSL::SSL::VERIFY_PEER | OpenSSL::SSL::VERIFY_FAIL_IF_NO_PEER_CERT})
+        OpenSSL::SSL::VERIFY_PEER | OpenSSL::SSL::VERIFY_FAIL_IF_NO_PEER_CERT })
 
-    temp_ca_cert = File.join(__dir__, 'ca_cert.pem')
-    temp_client_cert = File.join(__dir__, 'client.pem')
+    temp_ca_cert = File.join(__dir__, "ca_cert.pem")
+    temp_client_cert = File.join(__dir__, "client.pem")
 
     with_configured_fetcher(
       ":ssl_ca_cert: #{temp_ca_cert}\n" +
@@ -906,15 +989,15 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_do_not_allow_invalid_client_cert_auth_connection
     ssl_server = start_ssl_server({
       :SSLVerifyClient =>
-        OpenSSL::SSL::VERIFY_PEER | OpenSSL::SSL::VERIFY_FAIL_IF_NO_PEER_CERT})
+        OpenSSL::SSL::VERIFY_PEER | OpenSSL::SSL::VERIFY_FAIL_IF_NO_PEER_CERT })
 
-    temp_ca_cert = File.join(__dir__, 'ca_cert.pem')
-    temp_client_cert = File.join(__dir__, 'invalid_client.pem')
+    temp_ca_cert = File.join(__dir__, "ca_cert.pem")
+    temp_client_cert = File.join(__dir__, "invalid_client.pem")
 
     with_configured_fetcher(
       ":ssl_ca_cert: #{temp_ca_cert}\n" +
       ":ssl_client_cert: #{temp_client_cert}\n") do |fetcher|
-      assert_raises Gem::RemoteFetcher::FetchError do
+      assert_raise Gem::RemoteFetcher::FetchError do
         fetcher.fetch_path("https://localhost:#{ssl_server.config[:Port]}/yaml")
       end
     end
@@ -923,7 +1006,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def test_do_not_allow_insecure_ssl_connection_by_default
     ssl_server = start_ssl_server
     with_configured_fetcher do |fetcher|
-      assert_raises Gem::RemoteFetcher::FetchError do
+      assert_raise Gem::RemoteFetcher::FetchError do
         fetcher.fetch_path("https://localhost:#{ssl_server.config[:Port]}/yaml")
       end
     end
@@ -938,12 +1021,12 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def test_do_not_follow_insecure_redirect
     ssl_server = start_ssl_server
-    temp_ca_cert = File.join(__dir__, 'ca_cert.pem')
+    temp_ca_cert = File.join(__dir__, "ca_cert.pem")
     expected_error_message =
       "redirecting to non-https resource: #{@server_uri} (https://localhost:#{ssl_server.config[:Port]}/insecure_redirect?to=#{@server_uri})"
 
     with_configured_fetcher(":ssl_ca_cert: #{temp_ca_cert}") do |fetcher|
-      err = assert_raises Gem::RemoteFetcher::FetchError do
+      err = assert_raise Gem::RemoteFetcher::FetchError do
         fetcher.fetch_path("https://localhost:#{ssl_server.config[:Port]}/insecure_redirect?to=#{@server_uri}")
       end
 
@@ -956,7 +1039,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
     temp_ca_cert = nil
 
     with_configured_fetcher(":ssl_ca_cert: #{temp_ca_cert}") do |fetcher|
-      assert_raises Gem::RemoteFetcher::FetchError do
+      assert_raise Gem::RemoteFetcher::FetchError do
         fetcher.fetch_path("https://localhost:#{ssl_server.config[:Port]}")
       end
     end
@@ -964,8 +1047,8 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
 
   def with_configured_fetcher(config_str = nil, &block)
     if config_str
-      temp_conf = File.join @tempdir, '.gemrc'
-      File.open temp_conf, 'w' do |fp|
+      temp_conf = File.join @tempdir, ".gemrc"
+      File.open temp_conf, "w" do |fp|
         fp.puts config_str
       end
       Gem.configuration = Gem::ConfigFile.new %W[--config-file #{temp_conf}]
@@ -1046,7 +1129,7 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   end
 
   def start_ssl_server(config = {})
-    skip "starting this test server fails randomly on jruby" if Gem.java_platform?
+    pend "starting this test server fails randomly on jruby" if Gem.java_platform?
 
     null_logger = NilLog.new
     server = WEBrick::HTTPServer.new({
@@ -1054,9 +1137,9 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       :Logger => null_logger,
       :AccessLog => [],
       :SSLEnable => true,
-      :SSLCACertificateFile => File.join(__dir__, 'ca_cert.pem'),
-      :SSLCertificate => cert('ssl_cert.pem'),
-      :SSLPrivateKey => key('ssl_key.pem'),
+      :SSLCACertificateFile => File.join(__dir__, "ca_cert.pem"),
+      :SSLCertificate => cert("ssl_cert.pem"),
+      :SSLPrivateKey => key("ssl_key.pem"),
       :SSLVerifyClient => nil,
       :SSLCertName => nil,
     }.merge(config))
@@ -1064,18 +1147,16 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
       res.body = "--- true\n"
     end
     server.mount_proc("/insecure_redirect") do |req, res|
-      res.set_redirect(WEBrick::HTTPStatus::MovedPermanently, req.query['to'])
+      res.set_redirect(WEBrick::HTTPStatus::MovedPermanently, req.query["to"])
     end
     server.ssl_context.tmp_dh_callback = proc { TEST_KEY_DH2048 }
     t = Thread.new do
-      begin
-        server.start
-      rescue Exception => ex
-        puts "ERROR during server thread: #{ex.message}"
-        raise
-      ensure
-        server.shutdown
-      end
+      server.start
+    rescue Exception => ex
+      puts "ERROR during server thread: #{ex.message}"
+      raise
+    ensure
+      server.shutdown
     end
     while server.status != :Running
       sleep 0.1
@@ -1092,10 +1173,10 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
   def start_server(data)
     null_logger = NilLog.new
     s = WEBrick::HTTPServer.new(
-      :Port            => 0,
-      :DocumentRoot    => nil,
-      :Logger          => null_logger,
-      :AccessLog       => null_logger
+      :Port => 0,
+      :DocumentRoot => nil,
+      :Logger => null_logger,
+      :AccessLog => null_logger
     )
     s.mount_proc("/kill") {|req, res| s.shutdown }
     s.mount_proc("/yaml") do |req, res|
@@ -1103,32 +1184,30 @@ PeIQQkFng2VVot/WAQbv3ePqWq07g1BBcwIBAg==
         res.body = req["X-Captain"]
       elsif @enable_yaml
         res.body = data
-        res['Content-Type'] = 'text/plain'
-        res['content-length'] = data.size
+        res["Content-Type"] = "text/plain"
+        res["content-length"] = data.size
       else
         res.status = "404"
         res.body = "<h1>NOT FOUND</h1>"
-        res['Content-Type'] = 'text/html'
+        res["Content-Type"] = "text/html"
       end
     end
     s.mount_proc("/yaml.Z") do |req, res|
       if @enable_zip
         res.body = Zlib::Deflate.deflate(data)
-        res['Content-Type'] = 'text/plain'
+        res["Content-Type"] = "text/plain"
       else
         res.status = "404"
         res.body = "<h1>NOT FOUND</h1>"
-        res['Content-Type'] = 'text/html'
+        res["Content-Type"] = "text/html"
       end
     end
     th = Thread.new do
-      begin
-        s.start
-      rescue Exception => ex
-        abort "ERROR during server thread: #{ex.message}"
-      ensure
-        s.shutdown
-      end
+      s.start
+    rescue Exception => ex
+      abort "ERROR during server thread: #{ex.message}"
+    ensure
+      s.shutdown
     end
     th[:server] = s
     th
