@@ -1,7 +1,8 @@
 # frozen_string_literal: true
-require_relative 'helper'
-require 'rubygems/request_set'
-require 'rubygems/request_set/lockfile'
+
+require_relative "helper"
+require "rubygems/request_set"
+require "rubygems/request_set/lockfile"
 
 class TestGemRequestSetLockfile < Gem::TestCase
   def setup
@@ -9,7 +10,7 @@ class TestGemRequestSetLockfile < Gem::TestCase
 
     Gem::RemoteFetcher.fetcher = @fetcher = Gem::FakeFetcher.new
 
-    util_set_arch 'i686-darwin8.10.1'
+    util_set_arch "i686-darwin8.10.1"
 
     @set = Gem::RequestSet.new
 
@@ -19,7 +20,7 @@ class TestGemRequestSetLockfile < Gem::TestCase
     @set.instance_variable_set :@git_set,    @git_set
     @set.instance_variable_set :@vendor_set, @vendor_set
 
-    @gem_deps_file = 'gem.deps.rb'
+    @gem_deps_file = "gem.deps.rb"
   end
 
   def lockfile
@@ -29,19 +30,19 @@ class TestGemRequestSetLockfile < Gem::TestCase
   def write_lockfile(lockfile)
     @lock_file = File.expand_path "#{@gem_deps_file}.lock"
 
-    File.open @lock_file, 'w' do |io|
+    File.open @lock_file, "w" do |io|
       io.write lockfile
     end
   end
 
   def test_add_DEPENDENCIES
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2 do |s|
-        s.add_development_dependency 'b'
+      fetcher.spec "a", 2 do |s|
+        s.add_development_dependency "b"
       end
     end
 
-    @set.gem 'a'
+    @set.gem "a"
     @set.resolve
 
     out = []
@@ -49,8 +50,8 @@ class TestGemRequestSetLockfile < Gem::TestCase
     lockfile.add_DEPENDENCIES out
 
     expected = [
-      'DEPENDENCIES',
-      '  a',
+      "DEPENDENCIES",
+      "  a",
       nil,
     ]
 
@@ -59,14 +60,14 @@ class TestGemRequestSetLockfile < Gem::TestCase
 
   def test_add_DEPENDENCIES_from_gem_deps
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2 do |s|
-        s.add_development_dependency 'b'
+      fetcher.spec "a", 2 do |s|
+        s.add_development_dependency "b"
       end
     end
 
-    dependencies = { 'a' => Gem::Requirement.new('~> 2.0') }
+    dependencies = { "a" => Gem::Requirement.new("~> 2.0") }
 
-    @set.gem 'a'
+    @set.gem "a"
     @set.resolve
     @lockfile =
       Gem::RequestSet::Lockfile.new @set, @gem_deps_file, dependencies
@@ -76,8 +77,8 @@ class TestGemRequestSetLockfile < Gem::TestCase
     @lockfile.add_DEPENDENCIES out
 
     expected = [
-      'DEPENDENCIES',
-      '  a (~> 2.0)',
+      "DEPENDENCIES",
+      "  a (~> 2.0)",
       nil,
     ]
 
@@ -86,18 +87,18 @@ class TestGemRequestSetLockfile < Gem::TestCase
 
   def test_add_GEM
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2 do |s|
-        s.add_dependency 'b'
-        s.add_development_dependency 'c'
+      fetcher.spec "a", 2 do |s|
+        s.add_dependency "b"
+        s.add_development_dependency "c"
       end
 
-      fetcher.spec 'b', 2
+      fetcher.spec "b", 2
 
-      fetcher.spec 'bundler', 1
+      fetcher.spec "bundler", 1
     end
 
-    @set.gem 'a'
-    @set.gem 'bundler'
+    @set.gem "a"
+    @set.gem "bundler"
     @set.resolve
 
     out = []
@@ -105,12 +106,12 @@ class TestGemRequestSetLockfile < Gem::TestCase
     lockfile.add_GEM out, lockfile.spec_groups
 
     expected = [
-      'GEM',
-      '  remote: http://gems.example.com/',
-      '  specs:',
-      '    a (2)',
-      '      b',
-      '    b (2)',
+      "GEM",
+      "  remote: http://gems.example.com/",
+      "  specs:",
+      "    a (2)",
+      "      b",
+      "    b (2)",
       nil,
     ]
 
@@ -119,16 +120,16 @@ class TestGemRequestSetLockfile < Gem::TestCase
 
   def test_add_PLATFORMS
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2 do |s|
-        s.add_dependency 'b'
+      fetcher.spec "a", 2 do |s|
+        s.add_dependency "b"
       end
 
-      fetcher.spec 'b', 2 do |s|
+      fetcher.spec "b", 2 do |s|
         s.platform = Gem::Platform::CURRENT
       end
     end
 
-    @set.gem 'a'
+    @set.gem "a"
     @set.resolve
 
     out = []
@@ -136,9 +137,9 @@ class TestGemRequestSetLockfile < Gem::TestCase
     lockfile.add_PLATFORMS out
 
     expected = [
-      'PLATFORMS',
-      '  ruby',
-      '  x86-darwin-8',
+      "PLATFORMS",
+      "  ruby",
+      "  x86-darwin-8",
       nil,
     ]
 
@@ -146,21 +147,21 @@ class TestGemRequestSetLockfile < Gem::TestCase
   end
 
   def test_relative_path_from
-    path = lockfile.relative_path_from '/foo', '/foo/bar'
+    path = lockfile.relative_path_from "/foo", "/foo/bar"
 
-    assert_equal File.expand_path('/foo'), path
+    assert_equal File.expand_path("/foo"), path
 
-    path = lockfile.relative_path_from '/foo', '/foo'
+    path = lockfile.relative_path_from "/foo", "/foo"
 
-    assert_equal '.', path
+    assert_equal ".", path
   end
 
   def test_to_s_gem
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2
+      fetcher.spec "a", 2
     end
 
-    @set.gem 'a'
+    @set.gem "a"
 
     expected = <<-LOCKFILE
 GEM
@@ -180,12 +181,12 @@ DEPENDENCIES
 
   def test_to_s_gem_dependency
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2, 'c' => '>= 0', 'b' => '>= 0'
-      fetcher.spec 'b', 2
-      fetcher.spec 'c', 2
+      fetcher.spec "a", 2, "c" => ">= 0", "b" => ">= 0"
+      fetcher.spec "b", 2
+      fetcher.spec "c", 2
     end
 
-    @set.gem 'a'
+    @set.gem "a"
 
     expected = <<-LOCKFILE
 GEM
@@ -211,12 +212,12 @@ DEPENDENCIES
 
   def test_to_s_gem_dependency_non_default
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2, 'b' => '>= 1'
-      fetcher.spec 'b', 2
+      fetcher.spec "a", 2, "b" => ">= 1"
+      fetcher.spec "b", 2
     end
 
-    @set.gem 'b'
-    @set.gem 'a'
+    @set.gem "b"
+    @set.gem "a"
 
     expected = <<-LOCKFILE
 GEM
@@ -239,11 +240,11 @@ DEPENDENCIES
 
   def test_to_s_gem_dependency_requirement
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2, 'b' => '>= 0'
-      fetcher.spec 'b', 2
+      fetcher.spec "a", 2, "b" => ">= 0"
+      fetcher.spec "b", 2
     end
 
-    @set.gem 'a', '>= 1'
+    @set.gem "a", ">= 1"
 
     expected = <<-LOCKFILE
 GEM
@@ -269,7 +270,7 @@ DEPENDENCIES
 
     @vendor_set.add_vendor_gem name, directory
 
-    @set.gem 'a'
+    @set.gem "a"
 
     expected = <<-LOCKFILE
 PATH
@@ -292,7 +293,7 @@ DEPENDENCIES
 
     @vendor_set.add_vendor_gem name, File.expand_path(directory)
 
-    @set.gem 'a'
+    @set.gem "a"
 
     expected = <<-LOCKFILE
 PATH
@@ -312,12 +313,12 @@ DEPENDENCIES
 
   def test_to_s_gem_platform
     spec_fetcher do |fetcher|
-      fetcher.spec 'a', 2 do |spec|
+      fetcher.spec "a", 2 do |spec|
         spec.platform = Gem::Platform.local
       end
     end
 
-    @set.gem 'a'
+    @set.gem "a"
 
     expected = <<-LOCKFILE
 GEM
@@ -337,17 +338,17 @@ DEPENDENCIES
 
   def test_to_s_gem_source
     spec_fetcher do |fetcher|
-      fetcher.download 'a', 2
+      fetcher.download "a", 2
     end
 
-    spec_fetcher 'http://other.example/' do |fetcher|
-      fetcher.download 'b', 2
+    spec_fetcher "http://other.example/" do |fetcher|
+      fetcher.download "b", 2
     end
 
-    Gem.sources << 'http://other.example/'
+    Gem.sources << "http://other.example/"
 
-    @set.gem 'a'
-    @set.gem 'b'
+    @set.gem "a"
+    @set.gem "b"
 
     expected = <<-LOCKFILE
 GEM
@@ -377,43 +378,43 @@ DEPENDENCIES
     head = nil
 
     Dir.chdir repository do
-      FileUtils.mkdir 'b'
+      FileUtils.mkdir "b"
 
-      Dir.chdir 'b' do
-        b = Gem::Specification.new 'b', 1 do |s|
-          s.add_dependency 'a', '~> 1.0'
-          s.add_dependency 'c', '~> 1.0'
+      Dir.chdir "b" do
+        b = Gem::Specification.new "b", 1 do |s|
+          s.add_dependency "a", "~> 1.0"
+          s.add_dependency "c", "~> 1.0"
         end
 
-        File.open 'b.gemspec', 'w' do |io|
+        File.open "b.gemspec", "w" do |io|
           io.write b.to_ruby
         end
 
-        system @git, 'add', 'b.gemspec'
-        system @git, 'commit', '--quiet', '-m', 'add b/b.gemspec'
+        system @git, "add", "b.gemspec"
+        system @git, "commit", "--quiet", "-m", "add b/b.gemspec"
       end
 
-      FileUtils.mkdir 'c'
+      FileUtils.mkdir "c"
 
-      Dir.chdir 'c' do
-        c = Gem::Specification.new 'c', 1
+      Dir.chdir "c" do
+        c = Gem::Specification.new "c", 1
 
-        File.open 'c.gemspec', 'w' do |io|
+        File.open "c.gemspec", "w" do |io|
           io.write c.to_ruby
         end
 
-        system @git, 'add', 'c.gemspec'
-        system @git, 'commit', '--quiet', '-m', 'add c/c.gemspec'
+        system @git, "add", "c.gemspec"
+        system @git, "commit", "--quiet", "-m", "add c/c.gemspec"
       end
 
       head = `#{@git} rev-parse HEAD`.strip
     end
 
-    @git_set.add_git_gem 'a', repository, 'HEAD', true
-    @git_set.add_git_gem 'b', repository, 'HEAD', true
-    @git_set.add_git_gem 'c', repository, 'HEAD', true
+    @git_set.add_git_gem "a", repository, "HEAD", true
+    @git_set.add_git_gem "b", repository, "HEAD", true
+    @git_set.add_git_gem "c", repository, "HEAD", true
 
-    @set.gem 'b'
+    @set.gem "b"
 
     expected = <<-LOCKFILE
 GIT
@@ -449,12 +450,12 @@ DEPENDENCIES
   end
 
   def test_write_error
-    @set.gem 'nonexistent'
+    @set.gem "nonexistent"
 
     gem_deps_lock_file = "#{@gem_deps_file}.lock"
 
-    File.open gem_deps_lock_file, 'w' do |io|
-      io.write 'hello'
+    File.open gem_deps_lock_file, "w" do |io|
+      io.write "hello"
     end
 
     assert_raise Gem::UnsatisfiableDependencyError do
@@ -463,6 +464,6 @@ DEPENDENCIES
 
     assert_path_exist gem_deps_lock_file
 
-    assert_equal 'hello', File.read(gem_deps_lock_file)
+    assert_equal "hello", File.read(gem_deps_lock_file)
   end
 end
