@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
-require_relative "../util/changelog"
+require_relative "../tool/changelog"
 require "rubygems/commands/setup_command"
+require_relative "rubygems/helper"
 
 class ChangelogTest < Test::Unit::TestCase
   def setup
